@@ -1,5 +1,5 @@
 /*
- * $Id: CimXml.h,v 1.33 2008/08/07 18:25:40 tyreld Exp $
+ * $Id: CimXml.h,v 1.37 2009/06/24 17:44:48 tyreld Exp $
  *
  * CimXml.h
  *
@@ -33,10 +33,6 @@
 #include <vector>
 #include <iostream>
 
-#if defined __GNUC__
-#include <ansidecl.h>
-#endif
-
 using namespace std;
 
 extern int dumpXml;
@@ -59,7 +55,7 @@ class StringArray : public vector<string> {
    StringArray(int n) : vector<string>(n) {}
    StringArray(int n, const string& s) : vector<string>(n,s) {}
    void add(const string& t) { push_back(t); }
-   void toStringBuffer(string &sb, char *sep=" ",char *q="") {
+   void toStringBuffer(string &sb, const char *sep=" ",const char *q="") {
      for (size_type n=0; n<size(); n++) {
        sb = sb + (*this).at(n) + q;
        if (n!=size()-1) sb += sep;
@@ -103,9 +99,9 @@ class XmlBuffer {
    int endTag(const char*, const XmlAttr *a=NULL);
    int attrsOk(const XmlElement&,XmlAttr&,const char* tag);
    string getValue(const char *v=NULL);
-   char *getContent(const XmlAttr*);
+   const char *getContent(const XmlAttr*);
    int skipElement(const char*);
-   int testAttr(char*,char*,int);
+   int testAttr(const char*,const char*,int);
 };
 
 class DoesNotExist {
@@ -139,7 +135,7 @@ template<class T> class ArrayXml : public vector<T> {
    const T& operator[] (size_type n) const {return at(n);}
 #endif
    T *get(int n)    { return &(*this)[n]; }
-   void toStringBuffer(string &sb, char *sep=" ",char *q="") {
+   void toStringBuffer(string &sb, const char *sep=" ",const char *q="") {
      for (size_type n=0; n<this->size(); n++) {
        (*this).at(n).toStringBuffer(sb,q);
        if (n!=this->size()-1) sb += sep;
@@ -306,7 +302,7 @@ class KeyValueXml {
    KeyValueXml(const char*);
    KeyValueXml() {}
    KeyValueXml& operator=(const KeyValueXml& src) {if(this!=&src) {valType=src.valType; val = src.val;} return *this;}
-   void toStringBuffer(string&,char*);
+   void toStringBuffer(string&,const char*);
 };
 
 
@@ -316,7 +312,7 @@ class NameSpaceXml {
    string name;
    NameSpaceXml() {}
    NameSpaceXml(XmlBuffer&);
-   void toStringBuffer(string&,char*);
+   void toStringBuffer(string&,const char*);
 };
 
 class HostXml {
@@ -341,7 +337,7 @@ class NameSpacePathXml {
    LocalNameSpacePathXml lns;
    NameSpacePathXml() {}
    NameSpacePathXml(XmlBuffer&);
-   void toStringBuffer(string &sb, char *q="");
+   void toStringBuffer(string &sb, const char *q="");
 };
 
 class SubValueXml {
@@ -359,7 +355,7 @@ class SubValueXml {
 #define TypeSubValueInstancepath 4
 #define TypeSubValueClasspath 5
 #define TypeSubValueLocalClasspath 6
-   virtual void toStringBuffer(string &sb, char *q) { sb += ">>Not Supported>>"; }
+   virtual void toStringBuffer(string &sb, const char *q) { sb += ">>Not Supported>>"; }
 };
 
 class RetValXml {
@@ -387,7 +383,7 @@ class RetValXml {
    virtual RetValXml * clone() { return new RetValXml(*this); }
 #endif
    int getType() { return type; }
-   virtual void toStringBuffer(string &sb, char *q="") { sb += "** not implemented **"; }
+   virtual void toStringBuffer(string &sb, const char *q="") { sb += "** not implemented **"; }
 };
 
 class ValueXml : public RetValXml {
@@ -415,7 +411,7 @@ class ValueXml : public RetValXml {
    ValueXml * clone() { return new ValueXml(*this);}
    string getValue() { return val; }
    void toXmlBuffer(string &xb);
-   virtual void toStringBuffer(string&,char* q="");
+   virtual void toStringBuffer(string&,const char* q="");
 };
 
 class KeyBindingXml {
@@ -428,8 +424,8 @@ class KeyBindingXml {
    KeyBindingXml() : which(INVALID), name(0) {}
    KeyBindingXml(XmlBuffer&);
    void init(XmlBuffer&);
-   KeyBindingXml(char*,char*);
-   void toStringBuffer(string&,char*s="");
+   KeyBindingXml(const char*,const char*);
+   void toStringBuffer(string&,const char*s="");
 };
 
 
@@ -443,7 +439,7 @@ class InstanceNameXml : public RetValXml {
    InstanceNameXml(XmlBuffer&, char op=0);
    InstanceNameXml * clone() { return new InstanceNameXml(*this);}
    void init(XmlBuffer&, char op);
-   virtual void toStringBuffer(string&,char *q="");
+   virtual void toStringBuffer(string&,const char *q="");
 };
 
 class InstanceNamesXml : public RetValXml, public InstanceNameArray {
@@ -464,7 +460,7 @@ class InstancepathValueXml : public SubValueXml {
    InstancepathValueXml(XmlBuffer&);
    InstancepathValueXml * clone() { return new InstancepathValueXml(*this); }
    void init(XmlBuffer&);
-   virtual void toStringBuffer(string&,char*);
+   virtual void toStringBuffer(string&,const char*);
 };
 
 /*
@@ -483,7 +479,7 @@ class InstancenameValueXml : public SubValueXml {
    InstancenameValueXml(XmlBuffer&);
    InstancenameValueXml * clone() { return new InstancenameValueXml(*this); }
    void init(XmlBuffer&);
-   virtual void toStringBuffer(string&,char*);
+   virtual void toStringBuffer(string&,const char*);
 };
 
 class ClassnameValueXml : public SubValueXml {
@@ -501,7 +497,7 @@ class LocalInstancepathValueXml : public InstancepathValueXml {
    LocalInstancepathValueXml(XmlBuffer&);
    LocalInstancepathValueXml * clone() { return new LocalInstancepathValueXml(*this); }
    void init(XmlBuffer&);
-   virtual void toStringBuffer(string&,char*);
+   virtual void toStringBuffer(string&,const char*);
 };
 
 class PropertyXml {
@@ -526,29 +522,10 @@ class PropertyXml {
    PropertyXml(XmlBuffer&);
    PropertyXml(char*,int);
    void addQualifier(QualifierXml& q) { qualifiers.add(q); }
-   void toStringBuffer(string&,char*);
+   void toStringBuffer(string&,const char*);
    void toXmlBuffer(string&,AValue*,int vOnly=0,URL* url=NULL);
 };
 
-class MethodXml {
-   static XmlElement elm;
-   static bool initialized;
-   void   init(XmlBuffer&);
-   QualifierArray qualifiers;
-   ParameterArray parameters;
-  public:
-   string name;
-   string str;
-   MethodXml() : name("") {}
-   MethodXml(XmlBuffer&);
-   //   MethodXml * clone()    { return new MethodXml(*this); }
-   QualifierArray &getQualifiers()        { return qualifiers; }
-   ParameterArray &getParameters()        { return parameters; }
-   void addQualifier(QualifierXml& q)     { qualifiers.add(q); }
-   void addParameter(ParameterXml& p)     { parameters.add(p); }
-   //   void toStringBuffer(string&,char*);
-};
-
 class ParameterXml {
    static XmlElement elm,elmRef,elmArray, elmRefArray;
    static bool initialized;
@@ -572,10 +549,29 @@ class ParameterXml {
    ParameterXml(XmlBuffer&);
    //   ParameterXml(char*,int);
    void addQualifier(QualifierXml& q) { qualifiers.add(q); }
-   void toStringBuffer(string&,char*);
+   void toStringBuffer(string&,const char*);
    void toXmlBuffer(string&,AValue*,int vOnly=0,URL* url=NULL);
 };
 
+class MethodXml {
+   static XmlElement elm;
+   static bool initialized;
+   void   init(XmlBuffer&);
+   QualifierArray qualifiers;
+   ParameterArray parameters;
+  public:
+   string name;
+   string str;
+   MethodXml() : name("") {}
+   MethodXml(XmlBuffer&);
+   //   MethodXml * clone()    { return new MethodXml(*this); }
+   QualifierArray &getQualifiers()        { return qualifiers; }
+   ParameterArray &getParameters()        { return parameters; }
+   void addQualifier(QualifierXml& q)     { qualifiers.add(q); }
+   void addParameter(ParameterXml& p)     { parameters.add(p); }
+   //   void toStringBuffer(string&,char*);
+};
+
 class ClassXml : public RetValXml {
    static XmlElement elm;
    static bool initialized;
@@ -597,7 +593,7 @@ class ClassXml : public RetValXml {
    void addQualifier(QualifierXml& q)    { qualifiers.add(q);  }
    void addProperty(PropertyXml& p)      { properties.add(p); if (p.key) keys.add(p); }
    void addMethod(MethodXml& m)          { methods.add(m);     }
-   virtual void toStringBuffer(string&,char *q="");
+   virtual void toStringBuffer(string&,const char *q="");
    int keysOk(URL&);
 };
 
@@ -627,7 +623,7 @@ class InstanceXml : public RetValXml {
    QualifierArray &getQualifiers()    { return qualifiers; }
    void addQualifier(QualifierXml& q) { qualifiers.add(q); }
    void addProperty(PropertyXml& p)   { properties.add(p); }
-   virtual void toStringBuffer(string&,char *p="");
+   virtual void toStringBuffer(string&,const char *p="");
 };
 
 class NamedInstanceXml : public RetValXml {
@@ -692,7 +688,7 @@ class ClassNameXml : public RetValXml {
    ClassNameXml(XmlBuffer&);
    ClassNameXml * clone() { return new ClassNameXml(*this);}
    void init(XmlBuffer&);
-   virtual void toStringBuffer(string &sb, char *q="");
+   virtual void toStringBuffer(string &sb, const char *q="");
 };
 
 
@@ -715,7 +711,7 @@ class ParamvalueXml : public RetValXml {
   ParamvalueXml(const ParamvalueXml&);
   ~ParamvalueXml() {delete val;}
   ParamvalueXml *clone() {return new ParamvalueXml(*this);}
-  virtual void toStringBuffer(string &sb, char *q="");
+  virtual void toStringBuffer(string &sb, const char *q="");
 };
 
 class IReturnvalueXml {
@@ -779,7 +775,7 @@ class MethodresponseXml : public RetValXml,  public ResponseXml {
    MethodresponseXml(const MethodresponseXml &);
    ~MethodresponseXml() {delete rvl; delete pvll; delete err;}
    MethodresponseXml *clone() {return new MethodresponseXml(*this);};
-   virtual void toStringBuffer(string&,char *q="");
+   virtual void toStringBuffer(string&,const char *q="");
    virtual RetValXml *getReturnData() {
      if (err) throw ErrorXml(*err);
      return clone();
@@ -838,6 +834,7 @@ class URL {
    int  refLookAhead(char*,char**);
    void toStringBuffer(string&);
    void toStringBuffer(string&,int nsOnly);
+   void toStringBufferGI(string&);
 };
 
 #define INCLUDEQUAL false
@@ -848,7 +845,7 @@ class Cimom {
   static char xmlTrailer[];
  protected:
   virtual bool supportsSSL() { return false; };
-  virtual void genRequest(URL&,char*,bool cls=false,bool keys=false)=0;
+  virtual void genRequest(URL&,const char*,bool cls=false,bool keys=false)=0;
   virtual void addPayload(const string& pl)=0;
   virtual string getResponse()=0;
   char *newstr;
